@@ -5,7 +5,7 @@ class DelProperty(IndiMessage):
     from_device = True
 
     def __init__(self, device, name=None, timestamp=None, message=None, **junk):
-        self.device = device
+        super().__init__(device)
         self.name = name
         self.timestamp = timestamp
         self.message = message
