@@ -6,6 +6,6 @@ class EnableBLOB(IndiMessage):
     from_client = True
 
     def __init__(self, device, value, name=None, **junk):
-        self.device = device
+        super().__init__(device)
         self.name = name
         self.value = checks.dictionary(value, const.BLOBEnable)
